@@ -8,4 +8,6 @@
 from .class_name import prepare_class_name
 from .create import create_type, create_dataclass
 from .create_function import create_function, Missing
-from .hashable_dict import HashableDict
+
+# backward compatibility
+from frozendict import frozendict as HashableDict
