@@ -5,10 +5,19 @@
 #  ALL RIGHTS RESERVED.
 #
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
+import typing
 from typing import Any
 
 
 def prepare_class_name(bases: list[type], modifier: Any) -> str:
+    def to_str(value) -> str:
+        if typing.get_origin(value) == typing.Annotated:
+            args = typing.get_args(value)
+            value = args[0]
+            notes = [val for val in args[1:] if isinstance(val, str)]
+            return f'Annotated[{value}][{notes}]'
+        return str(value)
+
     def split_by_brackets(class_string: str) -> list[str]:
         parts = class_string.split("[")
         return parts
@@ -18,7 +27,7 @@ def prepare_class_name(bases: list[type], modifier: Any) -> str:
         return res
 
     name_base = "".join(
-        '_'.join(remove_import_path(part) for part in split_by_brackets(str(base)))
+        '_'.join(remove_import_path(part) for part in split_by_brackets(to_str(base)))
         for base in bases + [modifier]
     )
     name_base = name_base.replace("typing.", "")
